( cd etc ; rm -rf magic )
( cd etc ; ln -sf file/magic magic )
( cd usr/lib ; rm -rf libmagic.so.1 )
( cd usr/lib ; ln -sf libmagic.so.1.0.0 libmagic.so.1 )
( cd usr/lib ; rm -rf libmagic.so )
( cd usr/lib ; ln -sf libmagic.so.1.0.0 libmagic.so )
